/*
 * Author: 2006 Paolo Gai
 * CVS: $Id: code.c,v 1.10 2007/03/16 10:45:20 nino Exp $
 */
#define __USE_SPI__

#include "ee.h"
#include "cpu/pic30/inc/ee_irqstub.h"

// Primary (XT, HS, EC) Oscillator without PLL
_FOSCSEL(FNOSC_PRI);
// OSC2 Pin Function: OSC2 is Clock Output - Primary Oscillator Mode: XT Crystanl
_FOSC(OSCIOFNC_ON & POSCMD_XT);
// Watchdog Timer Enabled/disabled by user software
_FWDT(FWDTEN_OFF);
// Disable Code Protection
_FGS(GCP_OFF);            							

/* Program the Timer1 peripheral to raise interrupts */
void T1_program(void)
{
	T1CON = 0;		/* Stops the Timer1 and reset control reg	*/
	TMR1  = 0;		/* Clear contents of the timer register	*/
	PR1   = 0xffff;		/* Load the Period register wit the value 0xffff	*/
	IPC0bits.T1IP = 5;	/* Set Timer1 priority to 1		*/
	IFS0bits.T1IF = 0;	/* Clear the Timer1 interrupt status flag	*/
	IEC0bits.T1IE = 1;	/* Enable Timer1 interrupts		*/
	T1CONbits.TON = 1;	/* Start Timer1 with prescaler settings at 1:1
				* and clock source set to the internal 
				* instruction cycle			*/
}


/* Clear the Timer1 interrupt status flag */
void T1_clear(void)
{
	IFS0bits.T1IF = 0;
}

/* This is an ISR Type 2 which is attached to the Timer 1 peripheral IRQ pin
 * The ISR simply calls CounterTick to implement the timing reference
 */
ISR2(_T1Interrupt)
{
	/* clear the interrupt source */
	T1_clear();

	/* count the interrupts, waking up expired alarms */
	CounterTick(myCounter);
}

TASK(myTask)
{
	static int led_status = 0;
	SPI1BUF=0xaa;
  	LATAbits.LATA14 = !LATAbits.LATA14; 
  	if(SPI1BUF==75)
  		LATBbits.LATB14 = 1; 
  	if(SPI1BUF==80)
  		LATBbits.LATB14 = 0; 
	//LATBbits.LATB14 = !LATBbits.LATB14; 
}

int main(void)
{
	/* Program Timer 1 to raise interrupts */
	T1_program();
  	TRISAbits.TRISA14 = 0;
  	TRISBbits.TRISB14 = 0;
	/* Init led */
	//EE_leds_init();
	EE_spi_init_slave();
	IEC0bits.SPI1IE = 0;
	/* Program a cyclic alarm which will fire after an offset of 10 counter 
	* ticks, and after that periodically every 20 ticks */
	SetRelAlarm(myAlarm, 10, 2);
  
	/* A task can be activated directly by using ActivateTask */
	ActivateTask(myTask);
  
	/* Forever loop: background activities (if any) should go here */
	for (;;);
  
	return 0;
}
